import 'normalize.css/normalize.css';

import App from '../App';
import router, { constantRouterMap, routeStore } from '../router';
import store from '../store';
import createBaseFetch from './Api';
import configRoutePermission from './permission';

import '@/assets/styles/index.scss'; // global css
import extendCom from '@/utils/extends';
import { formatRouteLink } from '@/utils/route';

import storeModule from './storeModule';
import mixinModule from './mixins';
import utilsModule from './utils';

const fetch = createBaseFetch({
  timeout: 10000,
});

class SystemShell {
  constructor() {
    this.Api = fetch;
    this.storeModule = storeModule;
    this.mixinModule = mixinModule;
    this.utils = utilsModule;
  }
  createSystem = ({ routers, routeFilter }) => {
    routeStore.install(store);
    extendCom(Vue);
    configRoutePermission(router, store, routers);
    Vue.config.productionTip = false;

    let app = new Vue({
      el: '#app',
      router,
      store,
      render: h => {
        let routes = [...constantRouterMap];
        let allRoute = store.getters.asyncRoutes;
        if (typeof routeFilter === 'function') {
          allRoute = routeFilter(allRoute);
        }
        if (allRoute && allRoute.length) {
          let addRoute = formatRouteLink(allRoute);
          for (let index = 0; index < addRoute.length; index++) {
            const element = addRoute[index];
            if (element.children) {
              routes = routes.concat(element.children);
            }
          }
        }
        return <App route={routes} allRoutes={allRoute} />;
      },
    });
    return app;
  };
  createBaseFetch = createBaseFetch;
}
export default new SystemShell();
